{% extends 'base/layout.html' %}
{% load render_table from django_tables2 %}
{% load helpers %}

{% block title %}Z-Wave Devices{% endblock %}

{% block content %}
  <div class="row">
    <div class="col col-md-12">
      <div class="card">
        <h5 class="card-header">
          <div class="row">
            <div class="col">
              Z-Wave Devices
            </div>
            <div class="col col-md-auto text-end">
              <a href="{% url 'plugins:netbox_zwave:zwavedevice_add' %}" class="btn btn-primary">
                <span class="mdi mdi-plus-thick" aria-hidden="true"></span> Add Device
              </a>
            </div>
          </div>
        </h5>
        <div class="card-body">
          {% include 'inc/filter_list.html' %}
          {% render_table table %}
        </div>
      </div>
    </div>
  </div>
{% endblock %}
